@@ -17,7 +17,8 @@ class Enum:
     def options(cls):
         """Provide a sorted list of options."""
         return sorted(
-            (value, name) for (name, value) in __dict__inherited__(cls=cls, stop=Enum).items()
+            (value, name)
+            for (name, value) in __dict__inherited__(cls=cls, stop=Enum).items()
         )
 
     @classmethod
@@ -29,7 +30,8 @@ class Enum:
 class Multiplicity(Enum):
     """The various multiplicities that are accepted by KE-chain.
 
-    For more information on the representation in KE-chain, please consult the KE-chain `Part documentation`_.
+    For more information on the representation in KE-chain, please consult the KE-chain
+    `Part documentation`_.
 
     :cvar ZERO_ONE: Multiplicity 0 to 1
     :cvar ONE: Multiplicity 1
@@ -47,7 +49,8 @@ class Multiplicity(Enum):
 class Category(Enum):
     """The various categories of Parts that are accepted by KE-chain.
 
-    For more information on the representation in KE-chain, please consult the KE-chain `Part documentation`_.
+    For more information on the representation in KE-chain, please consult the KE-chain
+    `Part documentation`_.
 
     :cvar INSTANCE: Category of Instance
     :cvar MODEL: Category of Model
@@ -60,22 +63,26 @@ class Category(Enum):
 class Classification(Enum):
     """The various classification of Parts that are accepted by KE-chain.
 
-    For more information on the representation in KE-chain, please consult the KE-chain `Part documentation`_.
+    For more information on the representation in KE-chain, please consult the KE-chain
+    `Part documentation`_.
 
     :cvar PRODUCT: Classification of the part object is Product
     :cvar CATALOG: Classification of the part object is a CATALOG
 
-    .. _Part documentation: https://support.ke-chain.com/confluence/dosearchsite.action?queryString=concept+part
+    .. _Part documentation: https://support.ke-chain.com/confluence/dosearchsite.action?
+            queryString=concept+part
     """
 
     PRODUCT = "PRODUCT"
     CATALOG = "CATALOG"
+    FORM = "FORM"
 
 
 class PropertyType(Enum):
     """The various property types that are accepted by KE-chain.
 
-    For more information on the representation in KE-chain, please consult the KE-chain `Property documentation`_.
+    For more information on the representation in KE-chain, please consult the KE-chain
+    `Property documentation`_.
 
     :cvar CHAR_VALUE: a charfield property (single line text)
     :cvar TEXT_VALUE: text property (long text, may span multiple lines)
@@ -90,7 +97,8 @@ class PropertyType(Enum):
     .. versionadded:: 1.14
 
     :cvar SINGLE_SELECT_VALUE: single select list property (choose from a list)
-    :cvar REFERENCES_VALUE: a multi reference property, a list of UUID values referring to other part models
+    :cvar REFERENCES_VALUE: a multi reference property, a list of UUID values referring to
+        other part models
 
     .. versionadded:: 3.6
     :cvar ACTIVITY_REFERENCES_VALUE: Activity References Property
@@ -98,11 +106,17 @@ class PropertyType(Enum):
     :cvar SERVICE_REFERENCES_VALUE: Service Referenes Property
     :cvar TEAM_REFERENCES_VALUE: Team References Property
     :cvar USER_REFERENCES_VALUE: User References Property
+    :cvar FORM_REFERENCES_VALUE: Form References Property
+    :cvar CONTEXT_REFERENCES_VALUE: Context References Property
     :cvar JSON_VALUE: Generic JSON storage Property
     :cvar GEOJSON_VALUE: GEOJSON property to store map data
     :cvar WEATHER_VALUE: Weather JSON property compatible with the response of weatherapi.com
 
-    .. _Property documentation: https://support.ke-chain.com/confluence/dosearchsite.action?queryString=concept+property
+    .. versionadded:: 3.19
+    :cvar STATUS_REFERENCES_VALUE: Status References Property
+
+    .. _Property documentation: https://support.ke-chain.com/confluence/dosearchsite.action?
+        queryString=concept+property
     """
 
     CHAR_VALUE = "CHAR_VALUE"
@@ -122,6 +136,9 @@ class PropertyType(Enum):
     ACTIVITY_REFERENCES_VALUE = "ACTIVITY_REFERENCES_VALUE"
     SCOPE_REFERENCES_VALUE = "SCOPE_REFERENCES_VALUE"
     SERVICE_REFERENCES_VALUE = "SERVICE_REFERENCES_VALUE"
+    FORM_REFERENCES_VALUE = "FORM_REFERENCES_VALUE"
+    CONTEXT_REFERENCES_VALUE = "CONTEXT_REFERENCES_VALUE"
+    STATUS_REFERENCES_VALUE = "STATUS_REFERENCES_VALUE"
     TEAM_REFERENCES_VALUE = "TEAM_REFERENCES_VALUE"
     USER_REFERENCES_VALUE = "USER_REFERENCES_VALUE"
     JSON_VALUE = "JSON_VALUE"
@@ -387,27 +404,38 @@ class ServiceType(Enum):
 class ServiceEnvironmentVersion(Enum):
     """The acceptable versions of python where services run on.
 
-    :cvar PYTHON_3_6: Service execution environment is a python 3.6 container
+    :cvar PYTHON_3_6: Service execution environment is a python 3.6 container (unsupported)
     :cvar PYTHON_3_7: Service execution environment is a python 3.7 container
     :cvar PYTHON_3_8: Service execution environment is a python 3.8 container
-    :cvar PYTHON_3_6_NOTEBOOKS: execution environment is a python 3.6 container with jupyter notebook preinstalled
-    :cvar PYTHON_3_8_NOTEBOOKS: execution environment is a python 3.8 container with jupyter notebook preinstalled
+    :cvar PYTHON_3_9: Service execution environment is a python 3.9 container
+    :cvar PYTHON_3_10: Service execution environment is a python 3.10 container
+    :cvar PYTHON_3_6_NOTEBOOKS: execution environment is a python 3.6 container with jupyter
+        notebook preinstalled (unsupported)
+    :cvar PYTHON_3_8_NOTEBOOKS: execution environment is a python 3.8 container with jupyter
+        notebook preinstalled
+    :cvar PYTHON_3_9_NOTEBOOKS: execution environment is a python 3.9 container with jupyter
+        notebook preinstalled
+    :cvar PYTHON_3_10_NOTEBOOKS: execution environment is a python 3.10 container with jupyter
+        notebook preinstalled
     """
 
-    PYTHON_3_6 = "3.6"
+    PYTHON_3_6 = "3.6"  # unsupported
     PYTHON_3_7 = "3.7"
     PYTHON_3_8 = "3.8"
     PYTHON_3_9 = "3.9"
-    PYTHON_3_6_NOTEBOOKS = "3.6_notebook"
+    PYTHON_3_10 = "3.10"
+    PYTHON_3_6_NOTEBOOKS = "3.6_notebook"  # unsupported
     PYTHON_3_8_NOTEBOOKS = "3.8_notebook"
     PYTHON_3_9_NOTEBOOKS = "3.9_notebook"
+    PYTHON_3_10_NOTEBOOKS = "3.10_notebook"
 
 
 class ServiceScriptUser(Enum):
     """The acceptable usertypes under which a (trusted) service is run.
 
     :cvar KENODE_USER: Run as "kenode" user. Equivalent to a manager in a scope.
-    :cvar TEAMMANAGER_USER: Run as "kenode_team". Equivalent to a manager in a team. (disabled until available)
+    :cvar TEAMMANAGER_USER: Run as "kenode_team". Equivalent to a manager in a team.
+        (disabled until available)
     :cvar CONFIGURATOR_USER: Run as "kenode_configurator". Equivalent to GG:Configurator.
     """
 
@@ -453,8 +481,10 @@ class ScopeRoles(Enum):
     Roles that exist for a member of a scope.
 
     :cvar MANAGER: owner of the scope, has full rights
-    :cvar SUPERVISOR: supervisor member of a scope, has the rights as leadmember and rights to manage catalog tasks.
-    :cvar LEADMEMBER: elevated member, has assignment rights, no rights on App tasks or Catalog tasks.
+    :cvar SUPERVISOR: supervisor member of a scope, has the rights as leadmember and rights to
+        manage catalog tasks.
+    :cvar LEADMEMBER: elevated member, has assignment rights, no rights on App tasks or
+        Catalog tasks.
     :cvar MEMBER: normal member, only has viewing rights
     """
 
@@ -505,7 +535,8 @@ class ContextGroup(Enum):
     :cvar LOCATION: Location, in nl: Locatie
     :cvar PHASE: Phase, in nl: Fase
     :cvar REQUIREMENT: Requirement, in nl: Eis
-    :cvar EXTERNALID: External identifier, to be used to provide a generic link to an external application
+    :cvar EXTERNALID: External identifier, to be used to provide a generic link to an
+        external application
     :cvar WORKPACKAGE: Workpackage, in nl: Werkpakket
     """
 
@@ -525,13 +556,16 @@ class KechainEnv(Enum):
     """Environment variables that can be set for pykechain.
 
     :cvar KECHAIN_URL: full url of KE-chain where to connect to eg: 'https://<some>.ke-chain.com'
-    :cvar KECHAIN_TOKEN: authentication token for the KE-chain user provided from KE-chain user account control
+    :cvar KECHAIN_TOKEN: authentication token for the KE-chain user provided from KE-chain user
+        account control
     :cvar KECHAIN_USERNAME: the username for the credentials
     :cvar KECHAIN_PASSWORD: the password for the credentials
     :cvar KECHAIN_SCOPE: the name of the project / scope. Should be unique, otherwise use scope_id
     :cvar KECHAIN_SCOPE_ID: the UUID of the project / scope.
-    :cvar KECHAIN_FORCE_ENV_USE: set to 'true', '1', 'ok', or 'yes' to always use the environment variables.
-    :cvar KECHAIN_SCOPE_STATUS: the status of the Scope to retrieve, defaults to None to retrieve all scopes
+    :cvar KECHAIN_FORCE_ENV_USE: set to 'true', '1', 'ok', or 'yes' to always use the environment
+        variables.
+    :cvar KECHAIN_SCOPE_STATUS: the status of the Scope to retrieve, defaults to None to retrieve
+        all scopes
     :cvar KECHAIN_CHECK_CERTIFICATES: if the certificates of the URL should be checked.
     """
 
@@ -558,7 +592,7 @@ class SortTable(Enum):
 
 
 class Alignment(Enum):
-    """The acceptable alignment options for attachment viewer, navigation bar widgets and service widgets.
+    """The alignment options for attachment viewer, navigation bar widgets and service widgets.
 
     :cvar LEFT: Aligned to the left
     :cvar CENTER: Aligned to the center
@@ -576,6 +610,34 @@ class NavigationBarAlignment(Alignment):
     pass
 
 
+class SidebarItemAlignment(Enum):
+    """The acceptable alignment options for sidebar button.
+
+    :cvar TOP: "top"
+    :cvar BOTTOM: "bottom"
+    """
+
+    TOP = "top"
+    BOTTOM = "bottom"
+
+
+class SidebarButtonAlignment(SidebarItemAlignment):
+    """Compatibility enumeration class for the SidebarItemAlignment."""
+
+    pass
+
+
+class SidebarType(Enum):
+    """The types that can exist as a Sidebar Item.
+
+    :cvar BUTTON: a button,
+    :cvar CARD: a card
+    """
+
+    BUTTON = "BUTTON"
+    CARD = "CARD"
+
+
 class PaperSize(Enum):
     """The acceptable paper sizes options for a downloaded PDF.
 
@@ -701,10 +763,13 @@ class GeoCoordinateConfig(Enum):
     APPROX_ADDRESS = "approx_address"  # As approximated address
     # Amersfoort/RD (epsg: 28992) https://www.spatialreference.org/ref/epsg/amersfoort-rd-new/
     RD_AMERSFOORT = "rd_amersfoort"
-    DD = (  # As WSG84 (epsg:4326) decimal degrees representation first lat (-90,+90) then lng (-180,+180)
+    DD = (
+        # As WSG84 (epsg:4326) decimal degrees representation first lat (-90,+90) then lng
+        # (-180,+180)
         "dd"
     )
-    DMS = (  # As WSG84 (epsg:4326) degrees, minutes, seconds representation first lat N/S then lng E/W
+    DMS = (
+        # As WSG84 (epsg:4326) degrees, minutes, seconds representation first lat N/S then lng E/W
         "dms"
     )
 
@@ -881,16 +946,24 @@ class KEChainPages(Enum):
     URL names of built-in KE-chain pages.
 
     :cvar DETAIL: "detail"
+    :cvar FORMS: "forms"
     :cvar TASKS: "activities"
     :cvar WORK_BREAKDOWN: "activitytree"
+    :cvar CATALOG_FORMS: "catalogforms"
+    :cvar CONTEXTS: "contexts"
+    :cvar WORKFLOWS: "workflows"
     :cvar DATA_MODEL: "productmodel"
     :cvar EXPLORER: "product"
     :cvar SERVICES: "scripts"
     """
 
     DETAIL = "detail"
+    FORMS = "forms"
     TASKS = "activities"
     WORK_BREAKDOWN = "activitytree"
+    CATALOG_FORMS = "catalogforms"
+    CONTEXTS = "contexts"
+    WORKFLOWS = "workflows"
     DATA_MODEL = "productmodel"
     EXPLORER = "product"
     SERVICES = "scripts"
@@ -900,8 +973,12 @@ class KEChainPages(Enum):
 
 KEChainPageLabels = {
     KEChainPages.DETAIL: "Project details",
+    KEChainPages.FORMS: "Forms",
     KEChainPages.TASKS: "Tasks",
     KEChainPages.WORK_BREAKDOWN: "Work Breakdown",
+    KEChainPages.CATALOG_FORMS: "Template forms",
+    KEChainPages.CONTEXTS: "Contexts",
+    KEChainPages.WORKFLOWS: "Workflows",
     KEChainPages.CATALOG_WBS: "Catalog",
     KEChainPages.APP_WBS: "App Screens",
     KEChainPages.DATA_MODEL: "Data model",
@@ -911,8 +988,12 @@ KEChainPageLabels = {
 
 KEChainPageLabels_nl = {
     KEChainPages.DETAIL: "Project details",
+    KEChainPages.FORMS: "Formulieren",
     KEChainPages.TASKS: "Taken",
     KEChainPages.WORK_BREAKDOWN: "Taakverdeling",
+    KEChainPages.CATALOG_FORMS: "Sjablonen",
+    KEChainPages.CONTEXTS: "Contexten",
+    KEChainPages.WORKFLOWS: "Workflows",
     KEChainPages.CATALOG_WBS: "Catalogus",
     KEChainPages.APP_WBS: "App schermen",
     KEChainPages.DATA_MODEL: "Data model",
@@ -922,6 +1003,7 @@ KEChainPageLabels_nl = {
 
 CardWidgetKEChainPageLink = {
     KEChainPages.DETAIL: "Project",
+    KEChainPages.FORMS: "Forms",
     KEChainPages.TASKS: "Tasks",
     KEChainPages.DATA_MODEL: "Model",
     KEChainPages.EXPLORER: "Explorer",
@@ -929,12 +1011,19 @@ CardWidgetKEChainPageLink = {
     KEChainPages.WORK_BREAKDOWN: "Work Breakdown",
     KEChainPages.CATALOG_WBS: "Catalog Tasks",
     KEChainPages.APP_WBS: "App Tasks",
+    KEChainPages.CATALOG_FORMS: "Template forms",
+    KEChainPages.CONTEXTS: "Contexts",
+    KEChainPages.WORKFLOWS: "Workflows",
 }
 
 KEChainPageIcons = {
     KEChainPages.DETAIL: "bookmark",
+    KEChainPages.FORMS: "file-contract",
     KEChainPages.TASKS: "edit",
     KEChainPages.WORK_BREAKDOWN: "sitemap",
+    KEChainPages.CATALOG_FORMS: "file-export",
+    KEChainPages.CONTEXTS: "tags",
+    KEChainPages.WORKFLOWS: "directions",
     KEChainPages.CATALOG_WBS: "books",
     KEChainPages.APP_WBS: "tablet-alt",
     KEChainPages.DATA_MODEL: "cube",
@@ -961,10 +1050,20 @@ class URITarget(Enum):
 
     :cvar INTERNAL: "internal"
     :cvar EXTERNAL: "external"
+    :cvar NEW: "_new"
+    :cvar SELF: "_self"
+    :cvar BLANK: "_blank"
+    :cvar PARENT: "_parent"
+    :cvar TOP: "_top"
     """
 
     INTERNAL = "internal"
     EXTERNAL = "external"
+    NEW = "_new"
+    SELF = "_self"
+    BLANK = "_blank"
+    PARENT = "_parent"
+    TOP = "_top"
 
 
 class FontAwesomeMode(Enum):
@@ -984,6 +1083,34 @@ class FontAwesomeMode(Enum):
     LIGHT = "light"
 
 
+class SidebarAccessLevelOptions(Enum):
+    """
+    Options for access level options for the sidebar.
+
+    :cvar IS_MEMBER: "is_member"
+    :cvar IS_LEAD_MEMBER: "is_leadmember"
+    :cvar IS_SUPERVISOR: "is_supervisor"
+    :cvar IS_MANAGER: "is_manager"
+    """
+
+    IS_MEMBER = "is_member"
+    IS_LEAD_MEMBER = "is_leadmember"
+    IS_SUPERVISOR = "is_supervisor"
+    IS_MANAGER = "is_manager"
+
+
+class MinimumAccessLevelOptions(SidebarAccessLevelOptions):
+    """Options for minumum access level options for the sidebar."""
+
+    pass
+
+
+class MaximumAccessLevelOptions(SidebarAccessLevelOptions):
+    """Options for maximum access level options for the sidebar."""
+
+    pass
+
+
 class SelectListRepresentations(Enum):
     """
     Options in which a single-select list property options are displayed.
@@ -1043,7 +1170,8 @@ class NotificationStatus(Enum):
         next states: ARCHIVED
     - FAILED: when the message is not successfully sent out
         next states: ARCHIVED
-    - ARCHIVED: when the message is archives and waiting for its deletion against a certain retention policy
+    - ARCHIVED: when the message is archives and waiting for its deletion against a certain
+        retention policy
         next states: None
 
     :cvar ARCHIVED: "archived" notifications
@@ -1136,3 +1264,57 @@ class ImageSize(Enum):
     SQXL = "SQXL"
     XXL = "XXL"
     SQXXL = "SQXXL"
+
+
+class FormCategory(Enum):
+    """
+    Options for the Category of a Form.
+
+    :cvar MODEL: Model
+    :cvar INSTANCE: Instance
+    """
+
+    MODEL = "MODEL"
+    INSTANCE = "INSTANCE"
+
+
+class WorkflowCategory(Enum):
+    """
+    Options for the Category of a Workflow.
+
+    :cvar CATALOG: Catalog Workflow (immutable)
+    :cvar DEFINED: Defined Workflow belonging to a scope
+    """
+
+    CATALOG = "CATALOG"
+    DEFINED = "DEFINED"
+
+
+class TransitionType(Enum):
+    """
+    Options for the Type of a Transition.
+
+    :cvar INITIAL: Initial transition, the initial transition to follow when the form is created.
+    :cvar GLOBAL: Global transition, possibility to transition to all statuses from any
+    :cvar DIRECTED: A Directed transition, a transition with a specific from -> to direction
+    """
+
+    INITIAL = "INITIAL"
+    GLOBAL = "GLOBAL"
+    DIRECTED = "DIRECTED"
+
+
+class StatusCategory(Enum):
+    """
+    Category of statuses.
+
+    :cvar UNDEFINED: Undefined status
+    :cvar TODO: Todo status
+    :cvar INPROGRESS: In progress status
+    :cvar DONE: Done status
+    """
+
+    UNDEFINED = "UNDEFINED"
+    TODO = "TODO"
+    INPROGRESS = "INPROGRESS"
+    DONE = "DONE"
