@@ -1,38 +1,54 @@
 import datetime
 import os
 import time
-from typing import List, Dict, Optional, Union
+from typing import Dict, List, Optional, Union
 from urllib.parse import urljoin
 
 import requests
 
-from pykechain.defaults import ASYNC_REFRESH_INTERVAL, ASYNC_TIMEOUT_LIMIT, API_EXTRA_PARAMS
+from pykechain.defaults import (
+    API_EXTRA_PARAMS,
+    ASYNC_REFRESH_INTERVAL,
+    ASYNC_TIMEOUT_LIMIT,
+)
 from pykechain.enums import (
-    ActivityType,
-    ActivityStatus,
-    Category,
     ActivityClassification,
     ActivityRootNames,
-    PaperSize,
+    ActivityStatus,
+    ActivityType,
+    Category,
     PaperOrientation,
+    PaperSize,
+)
+from pykechain.exceptions import (
+    APIError,
+    IllegalArgumentError,
+    MultipleFoundError,
+    NotFoundError,
+    PDFDownloadTimeoutError,
 )
-from pykechain.exceptions import NotFoundError, IllegalArgumentError, APIError, MultipleFoundError
 from pykechain.models.input_checks import (
-    check_datetime,
-    check_text,
-    check_list_of_text,
-    check_enum,
-    check_user,
-    check_type,
     check_base,
+    check_datetime,
+    check_enum,
+    check_list_of_text,
+    check_text,
+    check_type,
+    check_user,
 )
 from pykechain.models.representations.component import RepresentationsComponent
 from pykechain.models.tags import TagsMixin
 from pykechain.models.tree_traversal import TreeObject
 from pykechain.models.user import User
 from pykechain.models.widgets.widgets_manager import WidgetsManager
-from pykechain.utils import get_offset_from_user_timezone, parse_datetime, is_valid_email, empty, \
-    Empty, clean_empty_values
+from pykechain.utils import (
+    Empty,
+    clean_empty_values,
+    empty,
+    get_offset_from_user_timezone,
+    is_valid_email,
+    parse_datetime,
+)
 
 
 class Activity(TreeObject, TagsMixin):
@@ -52,9 +68,11 @@ class Activity(TreeObject, TagsMixin):
     :type description: basestring
     :ivar status: status of the activity. One of :class:`pykechain.enums.ActivityStatus`
     :type status: basestring
-    :ivar classification: classification of the activity. One of :class:`pykechain.enums.ActivityClassification`
+    :ivar classification: classification of the activity. One of :class:
+        `pykechain.enums.ActivityClassification`
     :type classification: basestring
-    :ivar activity_type: Type of the activity. One of :class:`pykechain.enums.ActivityType` for WIM version 2
+    :ivar activity_type: Type of the activity. One of :class:`pykechain.enums.ActivityType`
+        for WIM version 2
     :type activity_type: basestring
     """
 
@@ -119,10 +137,11 @@ class Activity(TreeObject, TagsMixin):
         """
         Id of the scope this Activity belongs to.
 
-        This property will always produce a scope_id, even when the scope object was not included in an earlier
-        response.
+        This property will always produce a scope_id, even when the scope object was not included
+        in an earlier response.
 
-        When the :class:`Scope` is not included in this task, it will make an additional call to the KE-chain API.
+        When the :class:`Scope` is not included in this task, it will make an additional call to
+        the KE-chain API.
 
         :return: the scope id
         :type: uuid
@@ -155,16 +174,16 @@ class Activity(TreeObject, TagsMixin):
     # predicates
     #
 
-    def is_rootlevel(self):
+    def is_rootlevel(self) -> bool:
         """
-        Determine if the Activity is at the toplevel of a project, i.e. below the root itself.
+        Activity is at the toplevel of a project, i.e. below the root itself.
 
-        It will look for the name of the parent which should be either ActivityRootNames.WORKFLOW_ROOT or
-        ActivityRootNames.CATALOG_ROOT. If the name of the parent cannot be found an additional API call is made
-        to retrieve the parent object (based on the `parent_id` in the json_data).
+        It will look for the name of the parent which should be either
+        ActivityRootNames.WORKFLOW_ROOT or ActivityRootNames.CATALOG_ROOT. If the name of the
+        parent cannot be found an additional API call is made to retrieve the parent object (
+        based on the `parent_id` in the json_data).
 
         :return: Return True if it is a root level activity, otherwise return False
-        :rtype: bool
         """
         # when the activity itself is a root, than return False immediately
         if self.is_root():
@@ -180,102 +199,101 @@ class Activity(TreeObject, TagsMixin):
 
         return parent_name in ActivityRootNames.values()
 
-    def is_task(self):
+    def is_task(self) -> bool:
         """
-        Determine if the Activity is of ActivityType.TASK.
+        Activity is of ActivityType.TASK.
 
         :return: Return True if it is a task, otherwise return False
-        :rtype: bool
         """
         return self.activity_type == ActivityType.TASK
 
-    def is_subprocess(self):
+    def is_subprocess(self) -> bool:
         """
-        Determine if the Activity is of ActivityType.PROCESS.
+        Activity is of ActivityType.PROCESS.
 
         :return: Return True if it is a subprocess, otherwise return False
-        :rtype: bool
         """
         return self.is_process()
 
-    def is_process(self):
+    def is_process(self) -> bool:
         """
-        Determine if the Activity is of ActivityType.PROCESS.
+        Activity is of ActivityType.PROCESS.
 
         :return: Return True if it is a process, otherwise return False
-        :rtype: bool
         """
         return self.activity_type == ActivityType.PROCESS
 
-    def is_workflow(self):
+    def is_workflow(self) -> bool:
         """
-        Determine if the classification of the Activity is of ActivityClassification.WORKFLOW.
+        Classification of the Activity is of ActivityClassification.WORKFLOW.
 
         :return: Return True if it is a workflow classification activity, otherwise return False
-        :rtype: bool
         """
         return self.classification == ActivityClassification.WORKFLOW
 
-    def is_catalog(self):
+    def is_app(self) -> bool:
         """
-        Determine if the classification of the Activity is of ActivityClassification.CATALOG.
+        Classification of the Activity is of ActivityClassification.APP.
+
+        :return: Return True if it is a App classification activity, otherwise return False
+        """
+        return self.classification == ActivityClassification.APP
+
+    def is_catalog(self) -> bool:
+        """
+        Classification of the Activity is of ActivityClassification.CATALOG.
 
         :return: Return True if it is a catalog classification activity, otherwise return False
-        :rtype: bool
         """
         return self.classification == ActivityClassification.CATALOG
 
-    def is_workflow_root(self):
+    def is_workflow_root(self) -> bool:
         """
-        Determine if the classification of the Activity is of ActivityClassification.WORKFLOW and a ROOT object.
+        Classification of the Activity is of ActivityClassification.WORKFLOW and a ROOT object.
 
-        :return: Return True if it is a root workflow classification activity, otherwise return False
-        :rtype: bool
+        :return: Return True if it is a root workflow classification activity, otherwise False
         """
         return self.is_root() and self.is_workflow()
 
-    def is_catalog_root(self):
+    def is_catalog_root(self) -> bool:
         """
-        Determine if the classification of the Activity is of ActivityClassification.CATALOG and a ROOT object.
+        Classification of the Activity is of ActivityClassification.CATALOG and a ROOT object.
 
-        :return: Return True if it is a root catalog classification activity, otherwise return False
-        :rtype: bool
+        :return: Return True if it is a root catalog classification activity, otherwise False
         """
         return self.is_root() and self.is_catalog()
 
-    def is_root(self):
+    def is_root(self) -> bool:
         """
-        Determine if the Activity is a ROOT object.
+        Activity is a ROOT object.
 
-        If you want to determine if it is also a workflow or a catalog root, use :func:`Activity.is_workflow_root()`
-        or :func:`Activity.is_catalog_root()` methods.
+        If you want to determine if it is also a workflow or a catalog root,
+        use :func:`Activity.is_workflow_root()` or :func:`Activity.is_catalog_root()` methods.
 
         :return: Return True if it is a root object, otherwise return False
-        :rtype: bool
         """
         return self.name in ActivityRootNames.values() and self.parent_id is None
 
-    def is_configured(self):
+    def is_configured(self) -> bool:
         """
-        Determine if the Activity is configured with input and output properties.
+        Activity is configured with input and output properties.
 
-        Makes an additional lightweight call to the API to determine if any associated models are there.
+        Makes an additional lightweight call to the API to determine if any associated models
+        are there.
 
         :return: Return True if it is configured, otherwise return False
-        :rtype: bool
         """
         # check configured based on if we get at least 1 part back
         return bool(self.parts(category=Category.MODEL, limit=1))
 
-    def is_customized(self):
+    def is_customized(self) -> bool:
         """
-        Determine if the Activity is customized.
+        Activity is customized.
 
-        In other words if it has a customization. Use can use the :func:`Activity.customization()` to retrieve
-        the customization object and configure the task.
+        In other words if it has a customization. Use can use the :func:`Activity.customization()`
+        to retrieve the customization object and configure the task.
 
         :return: Return True if it is customized, otherwise return False
-        :rtype: bool
         """
         return bool(self._json_data.get("customization", False))
 
@@ -321,10 +339,12 @@ class Activity(TreeObject, TagsMixin):
     def children(self, **kwargs) -> List["Activity"]:
         """Retrieve the direct activities of this subprocess.
 
-        It returns a combination of Tasks (a.o. UserTasks) and Subprocesses on the direct descending level.
-        Only when the activity is a Subprocess, otherwise it raises a NotFoundError
+        It returns a combination of Tasks (a.o. UserTasks) and Subprocesses on the direct
+        descending level. Only when the activity is a Subprocess, otherwise it raises a
+        NotFoundError
 
-        :param kwargs: Additional search arguments, check :func:`pykechain.Client.activities` for additional info
+        :param kwargs: Additional search arguments, check :func:`pykechain.Client.activities`
+            for additional info
         :return: a list of :class:`Activity`
         :raises NotFoundError: when this task is not of type `ActivityType.PROCESS`
 
@@ -333,7 +353,8 @@ class Activity(TreeObject, TagsMixin):
         >>> task = project.activity('Subprocess')
         >>> children = task.children()
 
-        Example searching for children of a subprocess which contains a name (icontains searches case insensitive)
+        Example searching for children of a subprocess which contains a name (icontains searches
+        case insensitive)
 
         >>> task = project.activity('Subprocess')
         >>> children = task.children(name__icontains='more work')
@@ -353,9 +374,13 @@ class Activity(TreeObject, TagsMixin):
                     child._parent = self
             return self._cached_children
         else:
-            return self._client.activities(parent_id=self.id, scope=self.scope_id, **kwargs)
+            return self._client.activities(
+                parent_id=self.id, scope=self.scope_id, **kwargs
+            )
 
-    def child(self, name: Optional[str] = None, pk: Optional[str] = None, **kwargs) -> "Activity":
+    def child(
+        self, name: Optional[str] = None, pk: Optional[str] = None, **kwargs
+    ) -> "Activity":
         """
         Retrieve a child object.
 
@@ -391,7 +416,9 @@ class Activity(TreeObject, TagsMixin):
             child = activity_list[0]
 
         elif len(activity_list) > 1:
-            raise MultipleFoundError(f"{self} has more than one matching child.{criteria}")
+            raise MultipleFoundError(
+                f"{self} has more than one matching child.{criteria}"
+            )
         else:
             raise NotFoundError(f"{self} has no matching child.{criteria}")
         return child
@@ -399,10 +426,12 @@ class Activity(TreeObject, TagsMixin):
     def siblings(self, **kwargs) -> List["Activity"]:
         """Retrieve the other activities that also belong to the parent.
 
-        It returns a combination of Tasks (a.o. UserTasks) and Subprocesses on the level of the current task, including
-        itself. This also works if the activity is of type `ActivityType.PROCESS`.
+        It returns a combination of Tasks (a.o. UserTasks) and Subprocesses on the level of the
+        current task, including itself. This also works if the activity is of type
+        `ActivityType.PROCESS`.
 
-        :param kwargs: Additional search arguments, check :func:`pykechain.Client.activities` for additional info
+        :param kwargs: Additional search arguments, check :func:`pykechain.Client.activities`
+            for additional info
         :return: list of :class:`Activity`
         :raises NotFoundError: when it is a task in the top level of a project
 
@@ -420,7 +449,9 @@ class Activity(TreeObject, TagsMixin):
             raise NotFoundError(
                 f"Cannot find siblings for task '{self}', as this task exist on top level."
             )
-        return self._client.activities(parent_id=self.parent_id, scope=self.scope_id, **kwargs)
+        return self._client.activities(
+            parent_id=self.parent_id, scope=self.scope_id, **kwargs
+        )
 
     def all_children(self) -> List["Activity"]:
         """
@@ -461,7 +492,8 @@ class Activity(TreeObject, TagsMixin):
 
         :param parent: (O) parent Activity object or UUID
         :type parent: Activity
-        :param update_dict: (O) dictionary of new values to set on the cloned activities, e.g. `{"name": "New name"}`
+        :param update_dict: (O) dictionary of new values to set on the cloned activities,
+            e.g. `{"name": "New name"}`
         :type update_dict: dict
         :param kwargs: additional arguments, see the `Client.clone_activities()` method
         :return: clone of this activity
@@ -494,21 +526,21 @@ class Activity(TreeObject, TagsMixin):
         """
         Edit the activity and all its descendants with a single operation.
 
-        :param start_date: (optionally) edit the start date of the activity as a datetime object (UTC time/timezone
-                            aware preferred)
+        :param start_date: (optionally) edit the start date of the activity as a datetime object
+            (UTC time/timezone aware preferred)
         :type start_date: datetime or None
-        :param due_date: (optionally) edit the due_date of the activity as a datetime object (UTC time/timzeone
-                            aware preferred)
+        :param due_date: (optionally) edit the due_date of the activity as a datetime object
+            (UTC time/timzeone aware preferred)
         :type due_date: datetime or None
         :param assignees: (optionally) edit the assignees (usernames) of the activity as a list
         :type assignees: list(basestring) or None
         :param assignees_ids: (optionally) edit the assignees (user id's) of the activity as a list
         :type assignees_ids: list(basestring) or None
         :param status: (optionally) edit the status of the activity as a string based
-                       on :class:`~pykechain.enums.ActivityStatus`
+            on :class:`~pykechain.enums.ActivityStatus`
         :type status: ActivityStatus, basestring or None
         :param overwrite: (optionally) whether to overwrite existing assignees (True) or
-                          merge with existing assignees (False, default)
+            merge with existing assignees (False, default)
         :type overwrite: bool
 
         :return: flat list of the current task all descendants that have been edited
@@ -570,26 +602,27 @@ class Activity(TreeObject, TagsMixin):
         :type name: basestring or None or Empty
         :param description: (optionally) edit the description of the activity or clear it
         :type description: basestring or None or Empty
-        :param start_date: (optionally) edit the start date of the activity as a datetime object (UTC time/timezone
-                            aware preferred) or clear it
+        :param start_date: (optionally) edit the start date of the activity as a datetime object
+            (UTC time/timezone aware preferred) or clear it
         :type start_date: datetime or None or Empty
-        :param due_date: (optionally) edit the due_date of the activity as a datetime object (UTC time/timzeone
-                            aware preferred) or clear it
+        :param due_date: (optionally) edit the due_date of the activity as a datetime object
+            (UTC time/timzeone aware preferred) or clear it
         :type due_date: datetime or None or Empty
-        :param assignees: (optionally) edit the assignees (usernames) of the activity as a list, will overwrite all
-                          assignees or clear them
+        :param assignees: (optionally) edit the assignees (usernames) of the activity as a list,
+            will overwrite all assignees or clear them
         :type assignees: list(basestring) or None or Empty
-        :param assignees_ids: (optionally) edit the assignees (user id's) of the activity as a list, will overwrite all
-                             assignees or clear them
+        :param assignees_ids: (optionally) edit the assignees (user id's) of the activity as a
+            list, will overwrite all assignees or clear them
         :type assignees_ids: list(basestring) or None or Empty
-        :param status: (optionally) edit the status of the activity as a string based. Status cannot be cleared.
-                       on :class:`~pykechain.enums.ActivityStatus`
+        :param status: (optionally) edit the status of the activity as a string based. Status
+            cannot be cleared on :class:`~pykechain.enums.ActivityStatus`
         :type status: ActivityStatus or None or Empty
-        :param tags: (optionally) replace the tags on an activity, which is a list of strings ["one","two","three"]
-                    or clear them
+        :param tags: (optionally) replace the tags on an activity, which is a list of strings
+            ["one","two","three"] or clear them
         :type tags: list of basestring or None or Empty
 
-        :raises NotFoundError: if a `username` in the list of assignees is not in the list of scope members
+        :raises NotFoundError: if a `username` in the list of assignees is not in the list
+            of scope members
         :raises IllegalArgumentError: if the type of the inputs is not correct
         :raises APIError: if another Error occurs
         :warns: UserWarning - When a naive datetime is provided. Defaults to UTC.
@@ -598,18 +631,21 @@ class Activity(TreeObject, TagsMixin):
         -------
         >>> from datetime import datetime
         >>> my_task = project.activity('Specify the wheel diameter')
-        >>> my_task.edit(name='Specify wheel diameter and circumference',description='The diameter and circumference'
-        ... 'are specified in inches', start_date=datetime.utcnow(), assignee='testuser')
+        >>> my_task.edit(name='Specify wheel diameter and circumference',
+        ...     description='The diameter and circumference are specified in inches',
+        ...     start_date=datetime.utcnow(),
+        ...     assignee='testuser')
 
-        If we want to provide timezone aware datetime objects we can use the 3rd party convenience library :mod:`pytz`.
-        Mind that we need to fetch the timezone first and use `<timezone>.localize(<your datetime>)` to make it
-        work correctly.
+        If we want to provide timezone aware datetime objects we can use the 3rd party
+        convenience library :mod:`pytz`. Mind that we need to fetch the timezone first and use
+        `<timezone>.localize(<your datetime>)` to make it work correctly.
 
         Using `datetime(2017,6,1,23,59,0 tzinfo=<tz>)` does NOT work for most timezones with a
-        daylight saving time. Check the `pytz <http://pythonhosted.org/pytz/#localized-times-and-date-arithmetic>`_
-        documentation.
+        daylight saving time. Check the `pytz
+        <http://pythonhosted.org/pytz/#localized-times-and-date-arithmetic>`_ documentation.
 
-        To make it work using :mod:`pytz` and timezone aware :mod:`datetime` see the following example::
+        To make it work using :mod:`pytz` and timezone aware :mod:`datetime` see the following
+        example::
 
         >>> import pytz
         >>> start_date_tzaware = datetime.now(pytz.utc)
@@ -617,9 +653,9 @@ class Activity(TreeObject, TagsMixin):
         >>> due_date_tzaware = mytimezone.localize(datetime(2019, 10, 27, 23, 59, 0))
         >>> my_task.edit(start_date=start_date_tzaware,due_date=due_date_tzaware)
 
-        Not mentioning an input parameter in the function will leave it unchanged. Setting a parameter as None will
-        clear its value (where that is possible). The example below will clear the due_date, but leave everything else
-        unchanged.
+        Not mentioning an input parameter in the function will leave it unchanged. Setting a
+        parameter as None will clear its value (where that is possible). The example below will
+        clear the due_date, but leave everything else unchanged.
 
         >>> my_task.edit(due_date=None)
 
@@ -688,7 +724,9 @@ class Activity(TreeObject, TagsMixin):
             and not isinstance(assignees, Empty)
             and not isinstance(assignees_ids, Empty)
         ):
-            raise IllegalArgumentError("Provide either assignee names or their ids, but not both.")
+            raise IllegalArgumentError(
+                "Provide either assignee names or their ids, but not both."
+            )
         # Otherwise, pick the one that has a value specified which is not Empty
         else:
             assignees = (
@@ -712,7 +750,9 @@ class Activity(TreeObject, TagsMixin):
                 ]
 
                 if len(update_assignees_ids) != len(assignees):
-                    raise NotFoundError("All assignees should be a member of the project.")
+                    raise NotFoundError(
+                        "All assignees should be a member of the project."
+                    )
             else:
                 update_assignees_ids = list()
 
@@ -746,8 +786,8 @@ class Activity(TreeObject, TagsMixin):
 
         Without any arguments it retrieves the Instances related to this task only.
 
-        This call only returns the configured properties in an activity. So properties that are not configured
-        are not in the returned parts.
+        This call only returns the configured properties in an activity. So properties that are
+        not configured are not in the returned parts.
 
         See :class:`pykechain.Client.parts` for additional available parameters.
 
@@ -765,11 +805,11 @@ class Activity(TreeObject, TagsMixin):
     def associated_parts(self, *args, **kwargs):
         """Retrieve models and instances belonging to this activity.
 
-        This is a convenience method for the :func:`Activity.parts()` method, which is used to retrieve both the
-        `Category.MODEL` as well as the `Category.INSTANCE` in a tuple.
+        This is a convenience method for the :func:`Activity.parts()` method, which is used to
+        retrieve both the `Category.MODEL` as well as the `Category.INSTANCE` in a tuple.
 
-        This call only returns the configured properties in an activity. So properties that are not configured
-        are not in the returned parts.
+        This call only returns the configured properties in an activity. So properties that are
+        not configured are not in the returned parts.
 
         If you want to retrieve only the models associated to this task it is better to use:
             `task.parts(category=Category.MODEL)`.
@@ -787,16 +827,21 @@ class Activity(TreeObject, TagsMixin):
         associated_models = list()
         associated_instances = list()
         for widget in self.widgets():
-            associated_models.extend(widget.parts(category=Category.MODEL, *args, **kwargs))
-            associated_instances.extend(widget.parts(category=Category.INSTANCE, *args, **kwargs))
+            associated_models.extend(
+                widget.parts(category=Category.MODEL, *args, **kwargs)
+            )
+            associated_instances.extend(
+                widget.parts(category=Category.INSTANCE, *args, **kwargs)
+            )
 
         return (associated_models, associated_instances)
 
     def associated_object_ids(self) -> List[Dict]:
         """Retrieve object ids associated to this activity.
 
-        This represents a more in-depth retrieval of objects associated to the activity. Each element in the list
-        represents a `Property` of `Category.INSTANCE`. Each element contains the following fields:
+        This represents a more in-depth retrieval of objects associated to the activity. Each
+        element in the list represents a `Property` of `Category.INSTANCE`. Each element
+        contains the following fields:
 
         'id': The ID of the association
         'widget': The ID of the widget to which the Property instance is associated
@@ -848,7 +893,7 @@ class Activity(TreeObject, TagsMixin):
         :return: A :class:`WidgetManager` list, containing the widgets
         :rtype: WidgetManager
         :raises NotFoundError: when the widgets could not be found
-        :raises APIError: when the API does not support the widgets, or when the API gives an error.
+        :raises APIError: when the API does not support the widgets, or when API gives an error.
         """
         if self._widgets_manager is None:
             widgets = self._client.widgets(activity=self.id, **kwargs)
@@ -863,7 +908,8 @@ class Activity(TreeObject, TagsMixin):
         paper_orientation: PaperOrientation = PaperOrientation.PORTRAIT,
         include_appendices: bool = False,
         include_qr_code: bool = False,
-        user: Optional[User] = None
+        user: Optional[User] = None,
+        timeout: int = ASYNC_TIMEOUT_LIMIT,
     ) -> str:
         """
         Retrieve the PDF of the Activity.
@@ -871,27 +917,24 @@ class Activity(TreeObject, TagsMixin):
         .. versionadded:: 2.1
 
         :param target_dir: (optional) directory path name where the store the log.txt to.
-        :type target_dir: basestring or None
         :param pdf_filename: (optional) log filename to write the log to, defaults to `log.txt`.
-        :type pdf_filename: basestring or None
         :param paper_size: The size of the paper to which the PDF is downloaded:
                                - a4paper (default): A4 paper size
                                - a3paper: A3 paper size
                                - a2paper: A2 paper size
                                - a1paper: A1 paper size
                                - a0paper: A0 paper size
-        :type paper_size: basestring (see :class:`enums.PaperSize`)
         :param paper_orientation: The orientation of the paper to which the PDF is downloaded:
                                - portrait (default): portrait orientation
                                - landscape: landscape orientation
-        :type paper_size: basestring (see :class:`enums.PaperOrientation`)
-        :param include_appendices: True if the PDF should contain appendices, False (default) if otherwise.
-        :type include_appendices: bool
-        :param include_qr_code: True if the PDF should include a QR-code, False (default) if otherwise.
-        :type include_qr_code: bool
+        :param include_appendices: True if the PDF should contain appendices, False (default)
+            if otherwise.
+        :param include_qr_code: True if the PDF should include a QR-code, False (default)
+            if otherwise.
         :param user: (optional) used to calculate the offset needed to interpret Datetime
             Properties. Not having a user will simply use the default UTC.
-        :type user: User object
+        :param timeout: (optional) number of seconds to wait for the PDF to be created, defaults
+            to ASYNC_TIMEOUT_LIMIT
         :raises APIError: if the pdf file could not be found.
         :raises OSError: if the file could not be written.
         :returns Path to the saved pdf file
@@ -906,7 +949,9 @@ class Activity(TreeObject, TagsMixin):
 
         request_params = dict(
             papersize=check_enum(paper_size, PaperSize, "paper_size"),
-            orientation=check_enum(paper_orientation, PaperOrientation, "paper_orientation"),
+            orientation=check_enum(
+                paper_orientation, PaperOrientation, "paper_orientation"
+            ),
             appendices=check_type(include_appendices, bool, "include_appendices"),
             includeqr=check_type(include_qr_code, bool, "include_qr_code"),
         )
@@ -920,10 +965,11 @@ class Activity(TreeObject, TagsMixin):
         url = self._client._build_url("activity_export", activity_id=self.id)
         response = self._client._request("GET", url, params=request_params)
         if response.status_code != requests.codes.ok:  # pragma: no cover
-            raise APIError(f"Could not download PDF of Activity {self}", response=response)
+            raise APIError(
+                f"Could not download PDF of Activity {self}", response=response
+            )
 
         # If appendices are included, the request becomes asynchronous
-
         if include_appendices:  # pragma: no cover
             data = response.json()
 
@@ -931,8 +977,7 @@ class Activity(TreeObject, TagsMixin):
             url = urljoin(self._client.api_root, data["download_url"])
 
             count = 0
-
-            while count <= ASYNC_TIMEOUT_LIMIT:
+            while count <= timeout:
                 response = self._client._request("GET", url=url)
 
                 if response.status_code == requests.codes.ok:  # pragma: no cover
@@ -944,9 +989,9 @@ class Activity(TreeObject, TagsMixin):
                 count += ASYNC_REFRESH_INTERVAL
                 time.sleep(ASYNC_REFRESH_INTERVAL)
 
-            raise APIError(
-                "Could not download PDF of Activity {} within the time-out limit of {} "
-                "seconds".format(self, ASYNC_TIMEOUT_LIMIT),
+            raise PDFDownloadTimeoutError(
+                f"Could not download PDF of Activity {self} within the time-out limit "
+                f"of {timeout} seconds",
                 response=response,
             )
 
@@ -962,15 +1007,17 @@ class Activity(TreeObject, TagsMixin):
 
         See :func:`pykechain.Client.move_activity` for available parameters.
 
-        If you want to move an Activity from one classification to another, you need to provide the target
-        classification. The classification of the parent should match the one provided in the function. This is
-        to ensure that you really want this to happen.
+        If you want to move an Activity from one classification to another, you need to provide
+        the target classification. The classification of the parent should match the one
+        provided in the function. This is to ensure that you really want this to happen.
 
         :param parent: parent object to move activity to
         :type parent: Union[Activity, Text]
-        :param classification: (optional) classification of the target parent if you want to change the classification.
+        :param classification: (optional) classification of the target parent if you want to
+            change the classification.
         :type classification: ActivityClassification or None
-        :raises IllegalArgumentError: if the 'parent' activity_type is not :class:`enums.ActivityType.SUBPROCESS`
+        :raises IllegalArgumentError: if the 'parent' activity_type is not
+            :class:`enums.ActivityType.SUBPROCESS`
         :raises IllegalArgumentError: if the 'parent' type is not :class:`Activity` or UUID
         :raises APIError: if an Error occurs.
         """
@@ -1000,7 +1047,8 @@ class Activity(TreeObject, TagsMixin):
             message=check_text(message, "message"),
             subject=check_text(subject, "subject"),
             recipient_users=[
-                check_user(recipient, User, "recipient") for recipient in recipient_users
+                check_user(recipient, User, "recipient")
+                for recipient in recipient_users
             ],
             activity_id=self.id,
         )
@@ -1009,7 +1057,7 @@ class Activity(TreeObject, TagsMixin):
             check_user(from_user, User, "from_user")
             params.update(
                 from_user=from_user.id,
-                offset=get_offset_from_user_timezone(user=from_user)
+                offset=get_offset_from_user_timezone(user=from_user),
             )
 
         url = self._client._build_url("notification_share_activity_link")
@@ -1020,7 +1068,9 @@ class Activity(TreeObject, TagsMixin):
             requests.codes.created,
             requests.codes.accepted,
         ):  # pragma: no cover
-            raise APIError(f"Could not share the link to Activity {self}", response=response)
+            raise APIError(
+                f"Could not share the link to Activity {self}", response=response
+            )
 
     def share_pdf(
         self,
@@ -1056,9 +1106,11 @@ class Activity(TreeObject, TagsMixin):
         :type paper_size: basestring (see :class:`enums.PaperOrientation`)
         :param from_user: User that shared the PDF (optional)
         :type from_user: User object
-        :param include_appendices: True if the PDF should contain appendices, False (default) if otherwise.
+        :param include_appendices: True if the PDF should contain appendices, False (default)
+            if otherwise.
         :type include_appendices: bool
-        :param include_qr_code: True if the PDF should include a QR-code, False (default) if otherwise.
+        :param include_qr_code: True if the PDF should include a QR-code, False (default)
+            if otherwise.
         :type include_qr_code: bool
         :raises APIError: if an internal server error occurred.
         """
@@ -1085,7 +1137,9 @@ class Activity(TreeObject, TagsMixin):
             recipient_emails=recipient_emails,
             activity_id=self.id,
             papersize=check_enum(paper_size, PaperSize, "paper_size"),
-            orientation=check_enum(paper_orientation, PaperOrientation, "paper_orientation"),
+            orientation=check_enum(
+                paper_orientation, PaperOrientation, "paper_orientation"
+            ),
             appendices=check_type(include_appendices, bool, "include_appendices"),
             includeqr=check_type(include_qr_code, bool, "include_qr_code"),
         )
@@ -1094,7 +1148,7 @@ class Activity(TreeObject, TagsMixin):
             check_user(from_user, User, "from_user")
             params.update(
                 from_user=from_user.id,
-                offset=get_offset_from_user_timezone(user=from_user)
+                offset=get_offset_from_user_timezone(user=from_user),
             )
 
         url = self._client._build_url("notification_share_activity_pdf")
@@ -1105,7 +1159,9 @@ class Activity(TreeObject, TagsMixin):
             requests.codes.created,
             requests.codes.accepted,
         ):  # pragma: no cover
-            raise APIError(f"Could not share the link to Activity {self}", response=response)
+            raise APIError(
+                f"Could not share the link to Activity {self}", response=response
+            )
 
     #
     # Context Methods
@@ -1144,13 +1200,16 @@ class Activity(TreeObject, TagsMixin):
 
         :return: a Context object
         """
-        return self._client.create_context(scope=self.scope, actitivities=[self], **kwargs)
+        return self._client.create_context(
+            scope=self.scope, actitivities=[self], **kwargs
+        )
 
     def link_context(self, context: "Context") -> None:
         """
         Link the current activity to an existing Context.
 
-        If you want to link multiple activities at once, use the `Context.link_activities()` method.
+        If you want to link multiple activities at once,
+        use the `Context.link_activities()` method.
 
         :param context: A Context object to link the current activity to.
         :raises IllegalArgumentError: When the context is not a Context object.
@@ -1166,7 +1225,8 @@ class Activity(TreeObject, TagsMixin):
         """
         Link the current activity to an existing Context.
 
-        If you want to unlink multiple activities at once, use the `Context.unlink_activities()` method.
+        If you want to unlink multiple activities at once,
+        use the `Context.unlink_activities()` method.
 
         :param context: A Context object to unlink the current activity from.
         :raises IllegalArgumentError: When the context is not a Context object.
