@@ -94,7 +94,9 @@ class TestRepresentation(TestCase):
             empty_activity.representations = [representation]
 
     def test_component_invalid_property_type(self):
-        empty_prop = Property(json={"id": "1234567890", "category": "MODEL"}, client=None)
+        empty_prop = Property(
+            json={"id": "1234567890", "category": "MODEL"}, client=None
+        )
         representation = ThousandsSeparator(empty_prop)
         representation.rtype = "Broken rtype"
 
@@ -230,7 +232,9 @@ class Bases:
         incorrect_value = ["must be a string"]
 
         def test_set_mode(self):
-            representation = self.obj.representations[0]  # type: CustomIconRepresentation
+            representation = self.obj.representations[
+                0
+            ]  # type: CustomIconRepresentation
 
             # Set mode
             representation.display_mode = FontAwesomeMode.SOLID
@@ -242,7 +246,9 @@ class Bases:
             self.assertEqual(representation.display_mode, reloaded_repr.display_mode)
 
         def test_set_mode_incorrect(self):
-            representation = self.obj.representations[0]  # type: CustomIconRepresentation
+            representation = self.obj.representations[
+                0
+            ]  # type: CustomIconRepresentation
 
             with self.assertRaises(IllegalArgumentError):
                 representation.display_mode = "fancy colors"
@@ -294,7 +300,9 @@ class TestReprButton(Bases._TestPropertyRepresentation):
         self.obj.options = ["alpha", "beta", "gamma", "omega"]
 
 
-class TestUsePropertyNameRepresentationForPartReferences(Bases._TestPropertyRepresentation):
+class TestUsePropertyNameRepresentationForPartReferences(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.REFERENCES_VALUE
     representation_class = UsePropertyNameRepresentation
     value = True
@@ -321,35 +329,45 @@ class TestUsePropertyNameRepresentationForPartReferences(Bases._TestPropertyRepr
         self.assertIsNone(repr.value)
 
 
-class TestUsePropertyNameRepresentationForUserReferences(Bases._TestPropertyRepresentation):
+class TestUsePropertyNameRepresentationForUserReferences(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.USER_REFERENCES_VALUE
     representation_class = UsePropertyNameRepresentation
     value = True
     new_value = False
 
 
-class TestUsePropertyNameRepresentationForScopeReferences(Bases._TestPropertyRepresentation):
+class TestUsePropertyNameRepresentationForScopeReferences(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.SCOPE_REFERENCES_VALUE
     representation_class = UsePropertyNameRepresentation
     value = True
     new_value = False
 
 
-class TestUsePropertyNameRepresentationForServiceReferences(Bases._TestPropertyRepresentation):
+class TestUsePropertyNameRepresentationForServiceReferences(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.SERVICE_REFERENCES_VALUE
     representation_class = UsePropertyNameRepresentation
     value = True
     new_value = False
 
 
-class TestUsePropertyNameRepresentationForActivityReferences(Bases._TestPropertyRepresentation):
+class TestUsePropertyNameRepresentationForActivityReferences(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.ACTIVITY_REFERENCES_VALUE
     representation_class = UsePropertyNameRepresentation
     value = True
     new_value = False
 
 
-class TestUseCameraScannerInputRepresentationForCharProperties(Bases._TestPropertyRepresentation):
+class TestUseCameraScannerInputRepresentationForCharProperties(
+    Bases._TestPropertyRepresentation
+):
     property_type = PropertyType.CHAR_VALUE
     representation_class = CameraScannerInputRepresentation
     value = True
